You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@mesos.apache.org by gr...@apache.org on 2018/01/20 00:44:12 UTC

[2/7] mesos git commit: Renamed storage local resource provider tests to describe them better.

Renamed storage local resource provider tests to describe them better.

Review: https://reviews.apache.org/r/64994/


Project: http://git-wip-us.apache.org/repos/asf/mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/mesos/commit/a0283a9f
Tree: http://git-wip-us.apache.org/repos/asf/mesos/tree/a0283a9f
Diff: http://git-wip-us.apache.org/repos/asf/mesos/diff/a0283a9f

Branch: refs/heads/master
Commit: a0283a9f29354088e51f837ad61d776434070f3a
Parents: 4924443
Author: Chun-Hung Hsiao <ch...@mesosphere.io>
Authored: Fri Jan 19 15:36:24 2018 -0800
Committer: Greg Mann <gr...@gmail.com>
Committed: Fri Jan 19 15:49:03 2018 -0800

----------------------------------------------------------------------
 .../storage_local_resource_provider_tests.cpp   | 38 +++++++++-----------
 1 file changed, 17 insertions(+), 21 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/mesos/blob/a0283a9f/src/tests/storage_local_resource_provider_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/storage_local_resource_provider_tests.cpp b/src/tests/storage_local_resource_provider_tests.cpp
index d98b914..d5ec225 100644
--- a/src/tests/storage_local_resource_provider_tests.cpp
+++ b/src/tests/storage_local_resource_provider_tests.cpp
@@ -487,8 +487,8 @@ TEST_F(StorageLocalResourceProviderTest, ROOT_SmallDisk)
 
 
 // This test verifies that a framework can receive offers having new
-// storage pools from the storage local resource provider due to
-// adding new profiles.
+// storage pools from the storage local resource provider after a new
+// profile appears.
 TEST_F(StorageLocalResourceProviderTest, ROOT_NewProfile)
 {
   Clock::pause();
@@ -591,10 +591,9 @@ TEST_F(StorageLocalResourceProviderTest, ROOT_NewProfile)
 }
 
 
-// This test verifies that a framework can create then destroy a new
-// volume from the storage pool of a storage local resource provider
-// that uses the test CSI plugin.
-TEST_F(StorageLocalResourceProviderTest, ROOT_NewVolume)
+// This test verifies that the storage local resource provider can
+// create then destroy a new volume from a storage pool.
+TEST_F(StorageLocalResourceProviderTest, ROOT_CreateDestroyVolume)
 {
   loadUriDiskProfileModule();
 
@@ -771,10 +770,9 @@ TEST_F(StorageLocalResourceProviderTest, ROOT_NewVolume)
 }
 
 
-// This test verifies that a framework can destroy a new volume created
-// from the storage pool of a storage local resource provider that uses
-// the test CSI plugin after recovery.
-TEST_F(StorageLocalResourceProviderTest, ROOT_NewVolumeRecovery)
+// This test verifies that the storage local resource provider can
+// destroy a volume created from a storage pool after recovery.
+TEST_F(StorageLocalResourceProviderTest, ROOT_CreateDestroyVolumeRecovery)
 {
   loadUriDiskProfileModule();
 
@@ -967,10 +965,10 @@ TEST_F(StorageLocalResourceProviderTest, ROOT_NewVolumeRecovery)
 }
 
 
-// This test verifies that a framework can launch a task using a created
-// volume from a storage local resource provider that uses the test CSI
-// plugin, then destroy the volume while it is published.
-TEST_F(StorageLocalResourceProviderTest, ROOT_LaunchTask)
+// This test verifies that the storage local resource provider can
+// publish a volume required by a task, then destroy the published
+// volume after the task finishes.
+TEST_F(StorageLocalResourceProviderTest, ROOT_PublishResources)
 {
   loadUriDiskProfileModule();
 
@@ -1186,10 +1184,9 @@ TEST_F(StorageLocalResourceProviderTest, ROOT_LaunchTask)
 }
 
 
-// This test verifies that a framework can destroy a volume that was
-// created from a storage pool of a storage local resource provider
-// and used by a task after recovery.
-TEST_F(StorageLocalResourceProviderTest, ROOT_LaunchTaskRecovery)
+// This test verifies that the storage local resource provider can
+// destroy a published volume after recovery.
+TEST_F(StorageLocalResourceProviderTest, ROOT_PublishResourcesRecovery)
 {
   loadUriDiskProfileModule();
 
@@ -1419,9 +1416,8 @@ TEST_F(StorageLocalResourceProviderTest, ROOT_LaunchTaskRecovery)
 }
 
 
-// This test verifies that a framework can convert pre-existing volumes
-// from a storage local resource provider that uses the test CSI plugin
-// into mount or block volumes.
+// This test verifies that the storage local resource provider can
+// convert pre-existing CSI volumes into mount or block volumes.
 TEST_F(StorageLocalResourceProviderTest, ROOT_ConvertPreExistingVolume)
 {
   setupResourceProviderConfig(Bytes(0), "volume1:2GB;volume2:2GB");